| Title: | A Color Palette Generator |
|---|---|
| Description: | Color palettes from famous artists and paintings. |
| Authors: | Tomas Okal <[email protected]> |
| Maintainer: | Tomas Okal <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-14 06:32:40 UTC |
| Source: | https://github.com/tomasokal/rtist |
Use function to get a print of all palettes with painting and artist name.
rtist_help()rtist_help()
A printed list of rtist palettes with name of their associated painting and artist.
rtist_help()rtist_help()
Pick an artist name and number of colors desired.
rtist_palette(artist, n)rtist_palette(artist, n)
artist |
Name of desired artist palette. Choices are:
|
n |
Number of colors desired. All palettes have 5 colors. Most color schemes are derived from 10 Color Palettes Based on Famous Paintings. If omitted, will use all colors. |
A vector of colors.
rtist_palette("warhol") rtist_palette("pollock", 4)rtist_palette("warhol") rtist_palette("pollock", 4)
Use rtist_palette to construct palettes of desired length.
rtist_palettesrtist_palettes
An object of class list of length 15.